@@ -56,6 +56,11 @@ my %template = (
 		    "│ "  , # "\x{2502} "
 		    "╵ " ], # "\x{2575} "
     },
+    heavy_vbar => {
+	center => [ "╻ "  , # "\x{257b} "
+		    "┃ "  , # "\x{2503} "
+		    "╹ " ], # "\x{2579} "
+    },
     fence => {
 	left   => [ "╷ "  , # "\x{2577} "
 		    "│ "  , # "\x{2502} "
@@ -94,6 +99,19 @@ my %template = (
 		    "┘"   ],
 	bottom =>     "─",
     },
+    round_box => {
+	top    =>     "─",
+	left   => [  "╭─"  ,
+		     "│ "  ,
+		     "╰─" ],
+	center => [ "╮╭─"  ,
+		    "││ "  ,
+		    "╯╰─" ],
+	right  => [ "╮"    ,
+		    "│"    ,
+		    "╯"   ],
+	bottom =>     "─",
+    },
     frame => {
 	top    =>    "─",
 	bottom =>    "─",
